



if not exist %LIBRARY_BIN%\\las.dll exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %LIBRARY_LIB%\\las.lib exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %LIBRARY_INC%\\lasreader.hpp exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %LIBRARY_INC%\\laswriter.hpp exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
lasdiff -h
IF %ERRORLEVEL% NEQ 0 exit /B 1
las2txt -h
IF %ERRORLEVEL% NEQ 0 exit /B 1
lasindex -h
IF %ERRORLEVEL% NEQ 0 exit /B 1
lasmerge -h
IF %ERRORLEVEL% NEQ 0 exit /B 1
txt2las -h
IF %ERRORLEVEL% NEQ 0 exit /B 1
lasprecision -h
IF %ERRORLEVEL% NEQ 0 exit /B 1
las2las -h
IF %ERRORLEVEL% NEQ 0 exit /B 1
laszip -h
IF %ERRORLEVEL% NEQ 0 exit /B 1
lasinfo -h
IF %ERRORLEVEL% NEQ 0 exit /B 1
exit /B 0
